@@ -41,7 +41,6 @@ private:
 public:
 	subscriber();
 
-	bool classifier(rtpproxy::session *session, rtpproxy::session *source, struct sockaddr *addr);
 	void reload(service *cfg);
 	void start(service *cfg);
 	void stop(service *cfg);
@@ -80,7 +79,7 @@ void listener::run(void)
 		time(&now);
 		if(now > updated) {
 			updated = now + refresh;
-			rtpproxy::publish((const char *)published);
+			service::publish((const char *)published);
 		}
 	}
 	process::errlog(DEBUG1, "stopping rtpproxy thread");
@@ -92,6 +91,8 @@ modules::sipwitch()
 	memset(&provider, 0, sizeof(provider));
 	provider.rid = -1;
 	provider.type = MappedRegistry::EXTERNAL;
+	// we already know provider is normally external / outside NAT....
+	String::set(provider.network, sizeof(provider.network), "*");
 }
 
 void subscriber::update(void)
@@ -193,9 +194,12 @@ void subscriber::reload(service *cfg)
 				priority = atoi(value);
 			else if(!stricmp(key, "port") && !isConfigured())
 				port = atoi(value);
+			// very rare we may wish to override provider network/nat state
+			else if(!stricmp(key, "network"))
+				String::set(provider.network, sizeof(provider.network), value);
 			else if(!stricmp(key, "refresh"))
 				refresh = atoi(value);
-			else if(!stricmp(key, "publish") || !stricmp(key, "public")) {
+			else if(!stricmp(key, "publish") || !stricmp(key, "public") || !stricmp(key, "gateway")) {
 				vp = published;
 				published = strdup(value);
 				if(vp)
@@ -244,30 +248,6 @@ void subscriber::reload(service *cfg)
 		stats::allocate(1);
 }
 
-bool subscriber::classifier(rtpproxy::session *sid, rtpproxy::session *src, struct sockaddr *addr)
-{
-	// gateway mode on a router, we assume external calls are always through
-	// subscriber's sip provider, and hence require rtp proxy between isp
-	// and local user's subnet...
-	if(!sid)
-		return true;
-
-	sid->type = rtpproxy::NO_PROXY;
-
-	if(!addr)
-		addr = rtpproxy::getPublished();
-
-	Socket::getinterface((struct sockaddr *)(&sid->iface), addr);
-	if(sid != src) {
-		if(!Socket::equalhost((struct sockaddr *)(&sid->iface), (struct sockaddr *)(&src->iface))) {
-			sid->type = rtpproxy::GATEWAY_PROXY;
-			String::set(sid->network, sizeof(sid->network), "-");
-			return true;
-		}
-	}
-	return false;
-}
-
 void subscriber::registration(int id, modules::regmode_t mode) 
 {
 	if(id == -1 || id != provider.rid)
