@@ -435,7 +435,10 @@ void thread::invite(void)
 		snprintf(session->identity, sizeof(session->identity), "%s:%s@%s",
 			stack::sip.getScheme(), session->sysident, domain);
 
-		uri::identity(request_address.getAddr(), call->dialed, uri->username, sizeof(call->dialed));
+		if(destination == EXTERNAL)
+			uri::identity(request_address.getAddr(), call->dialed, uri->username, sizeof(call->dialed));
+		else
+			String::set(call->dialed, sizeof(call->dialed), dialing);
 
 		if(extension && !display[0])
 			snprintf(session->from, sizeof(session->from), 
@@ -534,10 +537,9 @@ exit:
 	debug(2, "call proceeding %08x:%u\n", session->sequence, session->cid);
 	return;
 
-noproxy:
-	send_reply(SIP_SERVICE_UNAVAILABLE);
-	call->failed(this, session);
-	return;
+// noproxy:
+//	send_reply(SIP_SERVICE_UNAVAILABLE);
+//	call->failed(this, session);
 }
 
 void thread::identify(void)
@@ -1288,7 +1290,7 @@ bool thread::getsource(void)
 	access = server::getPolicy(via_address.getAddr());
 	if(access) {
 		peering = access->iface;
-		String::set(network, sizeof(network), access->netname);
+		String::set(network, sizeof(network), access->getId());
 	}
 	else {
 		service::published(&peering);
