@@ -16,12 +16,23 @@
 // Transitional object for call information
 
 struct Calls {
+	char state[16];
 	char sid[32];
+	char display[64];
 	char source[96];
 	char target[96];
 	unsigned started, active;
 };
 
+struct Users {
+	char status[16];
+	char userid[48];
+	char service[16];
+	char extension[48];
+	char display[64];
+	unsigned active, trs;
+};
+	
 // Transitional object for primary server statistics
 
 struct Stats {
